@@ -4,7 +4,7 @@
 ### code chunk number 1: entropy_np.Rnw:70-72
 ###################################################
 library(np)
-options(prompt = "R> ", np.messages = FALSE, digits = 3)
+options(prompt = "R> ", np.messages = FALSE, digits = 3, warn = -1)
 
 
 ###################################################
